<?php
class Ameex_Insurance_CompanyController extends Mage_Adminhtml_Controller_Action
{
	public function indexAction()
	{
		$this->loadLayout();
		$this->_setActiveMenu('insurance/create_companies');
		$this->_addContent($this->getLayout()->createBlock('ameex_insurance/adminhtml_company_gridContainer'));
        $this->renderLayout();
	}
	
	public function exportCsvAction()
    {
        $fileName   = 'InsuranceCompanies.csv';
        $grid       = $this->getLayout()->createBlock('ameex_insurance/adminhtml_company_gridContainer_grid');
        $this->_prepareDownloadResponse($fileName, $grid->getCsvFile());
    }
    
    public function gridAction()
    {
        $this->loadLayout();
        $this->getResponse()->setBody(
               $this->getLayout()->createBlock('ameex_insurance/adminhtml_company_gridContainer_grid')->toHtml()
        );
    }
    
    public function editAction()
    {
        // Get id if available
        $id  = $this->getRequest()->getParam('id');
        $model = Mage::getModel('ameex_insurance/company');
     
        if ($id) {
            // Load record
            $model->load($id);
     
            // Check if record is loaded
            if (!$model->getId()) {
                Mage::getSingleton('adminhtml/session')->addError($this->__('This report no longer exists'));
                $this->_redirect('*/*/*');
     
                return;
            }  
        }  
     
        $this->_title("Edit Company");
        $data = Mage::getSingleton('adminhtml/session')->getFormData(true);
        if (!empty($data)) {
			$model->setData($data);
		}     
        Mage::register('insurance_company', $model);
     
        $this->loadLayout();		
		$this->_setActiveMenu('insurance/create_companies');
		$this->_addContent($this->getLayout()->createBlock('ameex_insurance/adminhtml_company_editFormContainer'))
			 ->_addLeft($this->getLayout()->createBlock('ameex_insurance/adminhtml_company_editFormContainer_edit_tabs'));
        $this->renderLayout();
	}
	
	public function newAction()
    {
        $this->loadLayout();		
		$this->_setActiveMenu('insurance/create_companies');
		$this->_addContent($this->getLayout()->createBlock('ameex_insurance/adminhtml_company_editFormContainer'))
			 ->_addLeft($this->getLayout()->createBlock('ameex_insurance/adminhtml_company_editFormContainer_edit_tabs'));
        $this->renderLayout();
    }
	
	public function saveAction()
	{
		if ($data = $this->getRequest()->getPost())
        {
            $model = Mage::getModel('ameex_insurance/company');
            $id = $this->getRequest()->getParam('id');
            if ($id)
            {
                $model->load($id);
            }
            $model->setData($data);
 
            Mage::getSingleton('adminhtml/session')->setFormData($data);
            try
            {
                if ($id)
                {
                    $model->setId($id);
                }
                $model->save();
 
                if (!$model->getId())
                {
                    Mage::throwException(Mage::helper('ameex_insurance')->__('Error while saving'));
                }
 
                Mage::getSingleton('adminhtml/session')->addSuccess(Mage::helper('ameex_insurance')->__('Insurance Company successfully saved.'));
                Mage::getSingleton('adminhtml/session')->setFormData(false);
 
                $this->_redirect('*/*/');
             }
             catch (Exception $e)
             {
                Mage::getSingleton('adminhtml/session')->addError($e->getMessage());
                if ($model && $model->getId())
                {
                    $this->_redirect('*/*/edit', array('id' => $model->getId()));
                }
                else
                {
                    $this->_redirect('*/*/');
                }
            } 
            return;
        }
        Mage::getSingleton('adminhtml/session')->addError(Mage::helper('ameex_insurance')->__('No data found to save'));
        $this->_redirect('*/*/');
	}
	
	public function deleteAction()
    {
        if ($id = $this->getRequest()->getParam('id')) {
            try {
                $model = Mage::getModel('ameex_insurance/company');
                $model->setId($id);
                $model->delete();
                Mage::getSingleton('adminhtml/session')->addSuccess(Mage::helper('ameex_insurance')->__('Deleted successfully.'));
                $this->_redirect('*/*/');
                return;
            }
            catch (Exception $e) {
                Mage::getSingleton('adminhtml/session')->addError($e->getMessage());
                $this->_redirect('*/*/edit', array('id' => $id));
                return;
            }
        }
        Mage::getSingleton('adminhtml/session')->addError(Mage::helper('ameex_insurance')->__('Unable to find the Insurance Company to delete.'));
        $this->_redirect('*/*/');
    }
    
    public function massDeleteAction()
	{
		$companyIds = $this->getRequest()->getParam('company_id');
		if(!is_array($companyIds)) {
			Mage::getSingleton('adminhtml/session')->addError(Mage::helper('ameex_insurance')->__('Please select Companies.'));
		}
		else {
			try {
				$companyModel = Mage::getModel('ameex_insurance/company');
				foreach ($companyIds as $companyId) {
					$companyModel->load($companyId)->delete();
				}
				Mage::getSingleton('adminhtml/session')->addSuccess(
					Mage::helper('ameex_insurance')->__('Total of %d record(s) were deleted.', count($companyIds))
				);
			}
			catch(Exception $e) {
				Mage::getSingleton('adminhtml/session')->addError($e->getMessage());
			}
		}
		 
		$this->_redirect('*/*/index');
	}
}
